if(!require("latticeExtra")) install.packages("latticeExtra", repos="http://cran.us.r-project.org")
library("latticeExtra")
if(!require("data.table")) install.packages("data.table", repos="http://cran.us.r-project.org")
library("data.table")

setwd(".../R_code_dataset")

#Results of model 1a
#Selecting upper bound of adult age group (60, 65 or 70)
x <- 65
load("Lambda_dataset.RData")
#Selecting only cohorts with age 0 to x   
lambda <- subset(lambda, age < x)
foo<-data.table(lambda)
foo[, min.age:= min(age), by=c("ctry","cohort", "cohorts", "onset")]
foo[, max.age:= max(age), by=c("ctry","cohort", "cohorts", "onset")]
foo <- lambda <- subset(foo, min.age == 0 & max.age == x-1)

#Calculating 5M0 and xM40
foo$age0_5 <-ifelse(foo$age<5,1,NA)
foo$age40_x <-ifelse(foo$age>=40 & foo$age<x,1,NA)
tmp <-foo[,list(
  M0_5  = -log(1-(1-prod(1-Qx*age0_5,na.rm=T))),
  M40_x = sum(Mx*age40_x,na.rm=T)),
  by=c("ctry","cohort", "cohorts",  "onset", "sex")]

#Excluding cohorts with few cases
foo<-data.table(tmp)
foo$count <- 1
n <-foo[,list(
  n= sum(count)),
  by=c("ctry", "cohorts")]
foo <- merge(foo, n, by = c("ctry", "cohorts"))
foo <- subset(foo, n > 5)

#Estimating the relation between 5M0 and xM40
coef_M40_x<-foo[,list(
  Beta = round(lm(log(M40_x) ~ log(M0_5))[[1]][2],2),
  SE = round(summary(lm(log(M40_x) ~ log(M0_5)))$coef[2,2],3),
  CI = paste("(",
             paste(round(lm(log(M40_x) ~ log(M0_5))[[1]][2] - 1.96*summary(lm(log(M40_x) ~ log(M0_5)))$coef[2,2],2),
                   round(lm(log(M40_x) ~ log(M0_5))[[1]][2] + 1.96*summary(lm(log(M40_x) ~ log(M0_5)))$coef[2,2],2), sep = ","),
             ")", sep= ""),
  R2 = round(summary(lm(log(M40_x) ~ log(M0_5)))$r.squared,2),
  n = length(cohort)),
  by=c("ctry", "cohorts",  "onset", "sex")]




#Results of model 2
#Selecting upper bound of adult age group (60, 65 or 70)
x <- 65
load("Lambda_dataset.RData")
#Selecting only cohorts with age 0 to x   
lambda <- subset(lambda, age < x)
foo<-data.table(lambda)
foo[, min.age:= min(age), by=c("ctry","cohort", "cohorts", "onset")]
foo[, max.age:= max(age), by=c("ctry","cohort", "cohorts", "onset")]
foo <- lambda <- subset(foo, min.age == 0 & max.age == x-1)

#Calculating 5M0 and xGS40 (Gompertz slope)
foo$age0_5 <-ifelse(foo$age<5,1,NA)
gomp<-function(age,Mx){
  datos<-data.frame(x=age-40,y=log(Mx))	
  md<-lm(y~x,dat=datos[age >= 40,])
  out<- coef(md)[2]
  return(out)	
}	
tmp <- foo[,list(
  M0_5= -log(1-(1-prod(1-Qx*age0_5,na.rm=T))),
  GS40_x = gomp(age,Mx)),
  by=c("ctry","cohort", "cohorts",  "onset", "sex")]

#Excluding cohorts with few cases
foo<-data.table(tmp)
foo$count <- 1
n <-foo[,list(
  n= sum(count)),
  by=c("ctry", "cohorts")]
foo <- merge(foo, n, by = c("ctry", "cohorts"))
foo <- subset(foo, n > 5)

#Estimating the relation between 5M0 and xG40
coef_G40_x<-foo[,list(
  Theta = round(lm(log(GS40_x) ~ log(M0_5))[[1]][2],2),
  SE = round(summary(lm(log(GS40_x) ~ log(M0_5)))$coef[2,2],3),
  CI = paste("(",
             paste(round(lm(log(GS40_x) ~ log(M0_5))[[1]][2] - 1.96*summary(lm(log(GS40_x) ~ log(M0_5)))$coef[2,2],2),
                   round(lm(log(GS40_x) ~ log(M0_5))[[1]][2] + 1.96*summary(lm(log(GS40_x) ~ log(M0_5)))$coef[2,2],2), sep = ","),
             ")", sep= ""),
  R2 = round(summary(lm(log(GS40_x) ~ log(M0_5)))$r.squared,2),
  n = length(cohort)),
  by=c("ctry", "onset", "cohorts", "sex")]




